@@ -35,12 +35,11 @@ class Id:
         # pylint: disable=no-self-use
 
         if self.type_ == Uuid:
-            return "id UUID DEFAULT uuid_generate_v4()"
+            return "id UUID DEFAULT data.uuid_generate_v4()"
         # self.type_ == Int64
-        return (
-            f"id UUID DEFAULT CAST"
-            f"(LPAD(TO_HEX(nextval('seq_{self.table_name}')), 32, '0') AS UUID)"
-        )
+        return (f"id UUID DEFAULT CAST ("
+                f"LPAD(TO_HEX(nextval('data.seq_{self.table_name}')), 32, '0')"
+                f" AS UUID)")
 
     def sql_constraints(self):
         """Returns the constraints for the "id" field."""
