@@ -151,12 +151,13 @@ class ToOneRelationship(Relationship):
         """Verifies the resource identifier object specified in a to-one
         relationship in the request document.
         """
+        if data_relationship_data is None:
+            return None
         relationship_type_name = self.rtable.collection.name
-        data_rio = data_relationship_data
 
         # Relationship type
         try:
-            data_rio_type_name = data_rio['type']
+            data_rio_type_name = data_relationship_data['type']
             if data_rio_type_name != relationship_type_name:
                 errors.append(
                     DocumentDataInvalidRelationshipTypeError(
@@ -174,7 +175,7 @@ class ToOneRelationship(Relationship):
 
         # Relationship id
         try:
-            data_rio_id_name = data_rio['id']
+            data_rio_id_name = data_relationship_data['id']
             try:
                 return IdValue(data_rio_id_name)
             except ValueError:
@@ -583,7 +584,7 @@ class OneToOneRemoteRelationship(ToOneRelationship):
 
     async def patch_object_task(self, env):
         """Updates the database with the one-to-one (remote) relationship
-        specified in a POST /{collection} request.
+        specified in a PATCH /{collection} request.
         """
         stmt = (f'UPDATE data.{self.rtable.name} '
                 f'SET {self.rfkey} = $1 '
@@ -893,7 +894,8 @@ class OneToManyRelationship(ToManyRelationship):
             log.debug(f'{stmt}: {env.id_number}, {data_id_numbers}')
             result = await env.connection.execute(stmt, env.id_number,
                                                   data_id_numbers)
-        if result == 'UPDATE 0':
+        count = int(result[len('UPDATE '):])
+        if count != len(data_id_numbers):
             env.cancel()
             raise NonexistentRelationshipIdError()
 
